<?php declare(strict_types=1);

namespace App\Controller;

use App\Entity\Gpu;
use App\Form\GpuType;
use App\Traits\FormControllerTrait;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\{Request, Response};
use Symfony\Component\Routing\Annotation\Route;

#[Route('/gpu')]
class GpuController extends AbstractController
{
    use FormControllerTrait;

    protected const ENTITY        = Gpu::class;
    protected const TEMPLATE_PATH = 'gpu/';
    protected const ROUTE_PREFIX  = 'gpu_';
    protected const FORM          = GpuType::class;

    public function __construct(private readonly EntityManagerInterface $entityManager)
    {
    }

    #[Route('/', name: 'gpu_index', methods: ['GET'])]
    public function index(): Response
    {
		$acquiredItems = $this->entityManager->getRepository(self::ENTITY)->findBy([
			'acquired' => TRUE,
		], []);
		$newItems = $this->entityManager->getRepository(self::ENTITY)->findBy([
			'acquired' => FALSE,
		], []);

		return $this->render('gpu/index.html.twig', [
			'not_acquired' => $newItems,
			'acquired' => $acquiredItems,
		]);
    }

    #[Route('/new', name: 'gpu_new', methods: ['GET', 'POST'])]
    public function new(Request $request): Response
    {
        return $this->itemCreate($request, 'gpu');
    }

    #[Route('/{id}', name: 'gpu_show', methods: ['GET'])]
    public function show(Gpu $gpu): Response
    {
        return $this->itemView($gpu, 'gpu');
    }

    #[Route('/{id}/edit', name: 'gpu_edit', methods: ['GET', 'POST'])]
    public function edit(Request $request, Gpu $gpu): Response
    {
        return $this->itemUpdate($request, $gpu, 'gpu');
    }

    #[Route('/{id}', name: 'gpu_delete', methods: ['POST'])]
    public function delete(Request $request, Gpu $gpu): Response
    {
        return $this->deleteCSRF($request, $gpu);
    }
}
